@@ -62,6 +62,59 @@ class BitcoinConf:
     WIF_NET_VER       = NetVersions(b"\x80", b"\xef")
 
 
+class BitcoinCashConf:
+    """ Class container for Bitcoin Cash configuration. """
+
+    # Names
+    NAMES                 = CoinNames("Bitcoin Cash"        , "BCH")
+    # Test names
+    TEST_NAMES            = CoinNames("Bitcoin Cash TestNet", "BCH")
+
+    # False for using Bitcoin Cash addresses, True for using Bitcoin legacy addresses
+    LEGACY_ADDR          = False
+
+    # BIP44 net versions (same of BIP32)
+    BIP44_KEY_NET_VER    = Bip32Conf.KEY_NET_VER
+    # BIP49 net versions (ypub / yprv) - (upub / uprv)
+    BIP49_KEY_NET_VER    = NetVersions(KeyNetVersions(b"049d7cb2", b"049d7878"),
+                                       KeyNetVersions(b"044a5262", b"044a4e28"))
+
+    # Versions for P2PKH address (Bitcoin Cash has HRP and net version)
+    BCH_P2PKH_NET_VER    = NetVersions({"hrp" : "bitcoincash", "net_ver" : b"\x00"},
+                                       {"hrp" : "bchtest"    , "net_ver" : b"\x00"})
+    # Versions for P2PKH legacy address (same of Bitcoin)
+    LEGACY_P2PKH_NET_VER = BitcoinConf.P2PKH_NET_VER
+    # Versions for P2SH address (Bitcoin Cash has HRP and net version)
+    BCH_P2SH_NET_VER     = NetVersions({"hrp" : "bitcoincash", "net_ver" : b"\x08"},
+                                       {"hrp" : "bchtest"    , "net_ver" : b"\x08"})
+    # Versions for P2PKH legacy address (same of Bitcoin)
+    LEGACY_P2SH_NET_VER  = BitcoinConf.P2SH_NET_VER
+    # WIF net version
+    WIF_NET_VER          = NetVersions(b"\x80", b"\xef")
+
+
+class BitcoinSvConf:
+    """ Class container for BitcoinSV configuration. """
+
+    # Names
+    NAMES             = CoinNames("BitcoinSV"        , "BSV")
+    # Test names
+    TEST_NAMES        = CoinNames("BitcoinSV TestNet", "BSV")
+
+    # BIP44 net versions (same of BIP32)
+    BIP44_KEY_NET_VER = Bip32Conf.KEY_NET_VER
+    # BIP49 net versions (ypub / yprv) - (upub / uprv)
+    BIP49_KEY_NET_VER = NetVersions(KeyNetVersions(b"049d7cb2", b"049d7878"),
+                                    KeyNetVersions(b"044a5262", b"044a4e28"))
+
+    # Versions for P2PKH address (same of Bitcoin)
+    P2PKH_NET_VER     = BitcoinConf.P2PKH_NET_VER
+    # Versions for P2SH address (same of Bitcoin)
+    P2SH_NET_VER      = BitcoinConf.P2SH_NET_VER
+    # WIF net version (same of Bitcoin)
+    WIF_NET_VER       = BitcoinConf.WIF_NET_VER
+
+
 class LitecoinConf:
     """ Class container for Litecoin configuration. """
 
@@ -76,12 +129,12 @@ class LitecoinConf:
     P2SH_DEPR_ADDR     = False
 
     # BIP44 net versions
-    # Litecoin can have 2 different main version: same of Bitcoin or (Ltpv / Ltub), test net version is (ttub / ttpv)
-    BIP44_KEY_NET_VER  = NetVersions((BitcoinConf.BIP44_KEY_NET_VER.Main(), KeyNetVersions(b"019da462", b"019d9cfe")),
+    # Litecoin can have 2 different main version: same of Bitcoin or (Ltpv / Ltub), whereas test net version is always (ttub / ttpv)
+    BIP44_KEY_NET_VER  = NetVersions({"btc" : BitcoinConf.BIP44_KEY_NET_VER.Main(), "alt" : KeyNetVersions(b"019da462", b"019d9cfe")},
                                      KeyNetVersions(b"0436f6e1", b"0436ef7d"))
     # BIP49 net versions
-    # Litecoin can have 2 different main version: same of Bitcoin or (Mtpv / Mtub), test net version is (ttub / ttpv)
-    BIP49_KEY_NET_VER  = NetVersions((BitcoinConf.BIP49_KEY_NET_VER.Main(), KeyNetVersions(b"01b26ef6", b"01b26792")),
+    # Litecoin can have 2 different main version: same of Bitcoin or (Mtpv / Mtub), whereas test net version is always (ttub / ttpv)
+    BIP49_KEY_NET_VER  = NetVersions({"btc" : BitcoinConf.BIP49_KEY_NET_VER.Main(), "alt" : KeyNetVersions(b"01b26ef6", b"01b26792")},
                                      KeyNetVersions(b"0436f6e1", b"0436ef7d"))
     # BIP84 net versions (zpub / zprv) - (ttub / ttpv)
     BIP84_KEY_NET_VER  = NetVersions(BitcoinConf.BIP84_KEY_NET_VER.Main(),
